"""Stub file for reflex_enterprise/components/mantine/dates.py"""

# ------------------- DO NOT EDIT ----------------------
# This file was generated by `reflex/utils/pyi_generator.py`!
# ------------------------------------------------------
from typing import Any, Callable, Literal, Mapping, Optional, Sequence, TypedDict

import reflex as rx
from reflex.components.component import Component
from reflex.components.core.breakpoints import Breakpoints
from reflex.event import EventType, PointerEventInfo
from reflex.vars.base import Var

from reflex_enterprise.components.component import ComponentEnterprise

from .base import (
    MantineDescriptionProps,
    MantineErrorProps,
    MantineLabelProps,
    MantineLeftSection,
    MantineRightSection,
)

MANTINE_DATES_PACKAGE = "@mantine/dates"
MANTINE_DATES_VERSION = "8.3.9"

class MantineDates(ComponentEnterprise):
    def add_imports(self): ...
    @classmethod
    def create(
        cls,
        *children,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        **props,
    ) -> "MantineDates":
        """Create the Reflex Enterprise component."""
        ...

class CalendarEvents(ComponentEnterprise):
    @classmethod
    def create(
        cls,
        *children,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "CalendarEvents":
        """Create the Reflex Enterprise component."""
        ...

class PresetEntry(TypedDict):
    value: str | tuple[str, str]
    label: str

class SharedCalendarProps(ComponentEnterprise):
    @classmethod
    def create(
        cls,
        *children,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        date: Var[str] | str | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        **props,
    ) -> "SharedCalendarProps":
        """Create the Reflex Enterprise component."""
        ...

class BareCalendar(MantineDates, SharedCalendarProps, CalendarEvents):
    @classmethod
    def create(
        cls,
        *children,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        date: Var[str] | str | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "BareCalendar":
        """Create the Reflex Enterprise component."""
        ...

class Calendar(BareCalendar):
    @classmethod
    def create(
        cls,
        *children,
        has_next_level: Var[bool] | bool | None = None,
        static: Var[bool] | bool | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        date: Var[str] | str | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "Calendar":
        """Create the Reflex Enterprise component."""
        ...

class BareCalendarPicker(
    BareCalendar,
    MantineLabelProps,
    MantineErrorProps,
    MantineDescriptionProps,
    MantineLeftSection,
    MantineRightSection,
):
    @classmethod
    def create(
        cls,
        *children,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        date: Var[str] | str | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "BareCalendarPicker":
        """Create the Reflex Enterprise component."""
        ...

class DateTimePicker(BareCalendarPicker):
    @classmethod
    def create(
        cls,
        *children,
        date: Var[str] | str | None = None,
        allow_deselect: Var[bool] | bool | None = None,
        allow_single_day_range: Var[bool] | bool | None = None,
        default_date: Var[str] | str | None = None,
        decade_label_format: Var[str] | str | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "DateTimePicker":
        """Create the Reflex Enterprise component."""
        ...

class DatePicker(BareCalendarPicker):
    @classmethod
    def create(
        cls,
        *children,
        date: Var[str] | str | None = None,
        type: Literal["default", "multiple", "range"]
        | Var[Literal["default", "multiple", "range"]]
        | None = None,
        allow_single_day_range: Var[bool] | bool | None = None,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "DatePicker":
        """Create the Reflex Enterprise component."""
        ...

class DatePickerInput(BareCalendarPicker):
    @classmethod
    def create(
        cls,
        *children,
        date: Var[str] | str | None = None,
        type: Literal["default", "multiple", "range"]
        | Var[Literal["default", "multiple", "range"]]
        | None = None,
        close_on_change: Var[bool] | bool | None = None,
        allow_single_day_range: Var[bool] | bool | None = None,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "DatePickerInput":
        """Create the Reflex Enterprise component."""
        ...

class DateInput(BareCalendarPicker):
    @classmethod
    def create(
        cls,
        *children,
        date: Var[str] | str | None = None,
        close_on_change: Var[bool] | bool | None = None,
        allow_single_day_range: Var[bool] | bool | None = None,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "DateInput":
        """Create the Reflex Enterprise component."""
        ...

class MonthPicker(BareCalendarPicker):
    @classmethod
    def create(
        cls,
        *children,
        date: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "MonthPicker":
        """Create the Reflex Enterprise component."""
        ...

class MonthPickerInput(BareCalendarPicker):
    @classmethod
    def create(
        cls,
        *children,
        date: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "MonthPickerInput":
        """Create the Reflex Enterprise component."""
        ...

class YearPicker(BareCalendarPicker):
    @classmethod
    def create(
        cls,
        *children,
        date: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "YearPicker":
        """Create the Reflex Enterprise component."""
        ...

class YearPickerInput(BareCalendarPicker):
    @classmethod
    def create(
        cls,
        *children,
        date: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "YearPickerInput":
        """Create the Reflex Enterprise component."""
        ...

class TimeInput(BareCalendarPicker):
    @classmethod
    def create(
        cls,
        *children,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        date: Var[str] | str | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "TimeInput":
        """Create the Reflex Enterprise component."""
        ...

class TimePicker(BareCalendarPicker):
    @classmethod
    def create(
        cls,
        *children,
        date: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "TimePicker":
        """Create the Reflex Enterprise component."""
        ...

class TimeGrid(BareCalendarPicker):
    @classmethod
    def create(
        cls,
        *children,
        data: Var[list[str]] | list[str] | None = None,
        placeholder: Var[str] | str | None = None,
        aria_labels: Var[dict[str, str]] | dict[str, str] | None = None,
        columns_to_scroll: Var[int] | int | None = None,
        date: Var[str] | str | None = None,
        decade_label_format: Var[str] | str | None = None,
        default_date: Var[str] | str | None = None,
        default_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        first_day_of_week: Var[int] | int | None = None,
        get_day_aria_label: Callable | Var[Callable] | None = None,
        get_day_props: Callable | Var[Callable] | None = None,
        get_month_control_props: Callable | Var[Callable] | None = None,
        get_year_control_props: Callable | Var[Callable] | None = None,
        hide_outside_dates: Var[bool] | bool | None = None,
        hide_weekdays: Var[bool] | bool | None = None,
        highlight_today: Var[bool] | bool | None = None,
        level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        locale: Var[str] | str | None = None,
        max_date: Var[str] | str | None = None,
        max_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        min_date: Var[str] | str | None = None,
        min_level: Literal["decade", "month", "year"]
        | Var[Literal["decade", "month", "year"]]
        | None = None,
        month_label_format: Var[str] | str | None = None,
        month_format: Var[str] | str | None = None,
        next_icon: Component | Var[Component] | None = None,
        next_label: Var[str] | str | None = None,
        number_of_columns: Var[int] | int | None = None,
        presets: Var[list[PresetEntry]] | list[PresetEntry] | None = None,
        previous_icon: Component | Var[Component] | None = None,
        previous_label: Var[str] | str | None = None,
        render_day: Callable | Var[Callable] | None = None,
        size: Literal["lg", "md", "sm", "xl", "xs"]
        | Var[Literal["lg", "md", "sm", "xl", "xs"]]
        | None = None,
        weekday_format: Var[str] | str | None = None,
        weekend_days: Var[list[int]] | list[int] | None = None,
        with_cell_spacing: Var[bool] | bool | None = None,
        with_week_numbers: Var[bool] | bool | None = None,
        year_label_format: Var[str] | str | None = None,
        year_list_format: Var[str] | str | None = None,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_change: Optional[EventType[()] | EventType[str]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_date_change: Optional[EventType[()] | EventType[str]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_level_change: Optional[EventType[()] | EventType[str]] = None,
        on_month_select: Optional[EventType[()] | EventType[str]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_next_decade: Optional[EventType[()] | EventType[str]] = None,
        on_next_month: Optional[EventType[()] | EventType[str]] = None,
        on_next_year: Optional[EventType[()] | EventType[str]] = None,
        on_previous_decade: Optional[EventType[()] | EventType[str]] = None,
        on_previous_month: Optional[EventType[()] | EventType[str]] = None,
        on_previous_year: Optional[EventType[()] | EventType[str]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        on_year_control_mouse_enter: Optional[EventType[()] | EventType[str]] = None,
        on_year_select: Optional[EventType[()] | EventType[str]] = None,
        **props,
    ) -> "TimeGrid":
        """Create the Reflex Enterprise component."""
        ...

class TimeValue(MantineDates):
    @classmethod
    def create(
        cls,
        *children,
        am_pm_labels: Var[dict[Literal["am", "pm"], str]]
        | dict[Literal["am", "pm"], str]
        | None = None,
        format: Literal["12h", "24h"] | Var[Literal["12h", "24h"]] | None = None,
        value: Var[str] | str | None = None,
        with_seconds: Var[bool] | bool | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        **props,
    ) -> "TimeValue":
        """Create the Reflex Enterprise component."""
        ...

class DatesNamespace(rx.ComponentNamespace):
    calendar = staticmethod(Calendar.create)
    date_time_picker = staticmethod(DateTimePicker.create)
    date_picker = staticmethod(DatePicker.create)
    date_picker_input = staticmethod(DatePickerInput.create)
    date_input = staticmethod(DateInput.create)
    month_picker = staticmethod(MonthPicker.create)
    month_picker_input = staticmethod(MonthPickerInput.create)
    year_picker = staticmethod(YearPicker.create)
    year_picker_input = staticmethod(YearPickerInput.create)
    time_input = staticmethod(TimeInput.create)
    time_picker = staticmethod(TimePicker.create)
    time_grid = staticmethod(TimeGrid.create)
    time_value = staticmethod(TimeValue.create)

dates = DatesNamespace()



"""Components for Reflex Enterprise."""

from __future__ import annotations

from reflex.utils import lazy_loader

_SUBMODULES: set[str] = {
    "ag_grid",
    "ag_charts",
    "flow",
    "mantine",
    "dnd",
    "map",
}

_SUBMOD_ATTRS: dict[str, list[str]] = {}

__getattr__, __dir__, __all__ = lazy_loader.attach(
    __name__,
    submodules=_SUBMODULES,
    submod_attrs=_SUBMOD_ATTRS,
)



"""You can create a new node when you drop the connection line on the pane by using the onConnectStart and onConnectEnd handlers."""

import reflex as rx

import reflex_enterprise as rxe
from reflex_enterprise.components.flow.types import (
    ConnectionInProgress,
    Edge,
    NoConnection,
    Node,
    XYPosition,
)

initial_nodes: list[Node] = [
    {
        "id": "0",
        "type": "input",
        "data": {"label": "Node"},
        "position": {"x": 0, "y": 50},
    },
]


class AddNodesOnEdgeDropState(rx.State):
    nodes: rx.Field[list[Node]] = rx.field(default_factory=lambda: initial_nodes)
    edges: rx.Field[list[Edge]] = rx.field(default_factory=list)
    node_id: int = 1

    @rx.event
    def increment(self):
        self.node_id += 1

    @rx.event
    def set_nodes(self, nodes: list[Node]):
        self.nodes = nodes

    @rx.event
    def set_edges(self, edges: list[Edge]):
        self.edges = edges

    @rx.event
    def handle_connect_end(
        self,
        connection_status: NoConnection | ConnectionInProgress,
        event: rx.event.PointerEventInfo,
        flow_position: XYPosition,
    ):
        if not connection_status["isValid"]:
            node_id = str(self.node_id)
            self.increment()
            self.nodes.append(
                {
                    "id": node_id,
                    "position": flow_position,
                    "data": {"label": f"Node {node_id}"},
                    "origin": (0.5, 0.0),
                }
            )
            self.edges.append(
                {
                    "id": node_id,
                    "source": connection_status["fromNode"]["id"],
                    "target": node_id,
                }
            )


@rx.page(route="/nodes/add-node-on-edge-drop", title="Add Node on Edge Drop Demo")
def add_node_on_edge_drop():
    return rx.box(
        rxe.flow.provider(
            rxe.flow(
                rxe.flow.background(),
                on_connect=lambda connection: AddNodesOnEdgeDropState.set_edges(
                    rxe.flow.util.add_edge(connection, AddNodesOnEdgeDropState.edges)
                ),
                on_connect_end=(
                    lambda connection_status, event: (
                        AddNodesOnEdgeDropState.handle_connect_end(
                            connection_status,
                            event,
                            rxe.flow.api.screen_to_flow_position(
                                x=event.client_x,
                                y=event.client_y,
                            ),
                        )
                    )
                ),
                nodes=AddNodesOnEdgeDropState.nodes,
                edges=AddNodesOnEdgeDropState.edges,
                on_nodes_change=lambda changes: AddNodesOnEdgeDropState.set_nodes(
                    rxe.flow.util.apply_node_changes(
                        AddNodesOnEdgeDropState.nodes, changes
                    )
                ),
                on_edges_change=lambda changes: AddNodesOnEdgeDropState.set_edges(
                    rxe.flow.util.apply_edge_changes(
                        AddNodesOnEdgeDropState.edges, changes
                    )
                ),
                color_mode="light",
                fit_view=True,
                fit_view_options={"padding": 2},
                node_origin=(0.5, 0.0),
            )
        ),
        height="100vh",
        width="100vw",
    )



"""AG Grid Demo."""

import reflex as rx

import reflex_enterprise as rxe

from .aligned_grids import aligned_grids_page
from .cell_selection import cell_selection_page
from .common import DemoState, demo
from .editable import editable_page
from .fill_handle import fill_handle_page
from .formatters import formatter_page
from .grid_state_serialization import grid_state_serialization_simple_page
from .grid_state_serialization_advanced import grid_state_serialization_advanced_page
from .integrated_charts import integrated_chart_page
from .master_detail import master_detail_page
from .model_wrapper_customized import model_page_auth
from .model_wrapper_simple import model_page
from .model_wrapper_ssrm import model_page_ssrm
from .pivot import pivot_page
from .selected_items import selected_items_example
from .state_grid import state_grid_page
from .tree import tree_example

__all__ = [
    "aligned_grids_page",
    "app",
    "cell_selection_page",
    "editable_page",
    "fill_handle_page",
    "formatter_page",
    "grid_state_serialization_advanced_page",
    "grid_state_serialization_simple_page",
    "integrated_chart_page",
    "master_detail_page",
    "model_page",
    "model_page_auth",
    "model_page_ssrm",
    "pivot_page",
    "selected_items_example",
    "state_grid_page",
    "tree_example",
]


@demo(
    route="/",
    title="AG Grid Demo",
    description="A collection of examples using AG Grid in Reflex.",
)
def index():
    """Index page for the AG Grid demos."""
    return rx.flex(
        rx.foreach(
            DemoState.pages,
            lambda page: rx.card(
                rx.vstack(
                    rx.link(page.title, href=page.route),
                    rx.text(page.description),
                ),
                width="300px",
            ),
        ),
        wrap="wrap",
        spacing="3",
    )


# Add state and page to the app.
app = rxe.App()

# Uncomment this when deploying demos, to initialize the database.
# rx.utils.prerequisites.check_db_initialized() or rx.Model.alembic_init()
# rx.Model.migrate(autogenerate=True)



"""Secure cookie implementation for use with authentication secrets."""

import asyncio
import contextlib
from functools import lru_cache
from typing import Any, ClassVar, get_type_hints, overload

import reflex as rx
from reflex.constants.state import FIELD_MARKER
from reflex.event import EventSpec, IndividualEventType, fix_events
from reflex.state import BaseState, StateUpdate, _substate_key
from reflex.utils.prerequisites import get_app
from reflex.utils.types import is_optional
from starlette.requests import Request, cookie_parser
from starlette.responses import Response
from starlette.routing import Route

from reflex_enterprise.utils import fetch, get_backend_url
from reflex_enterprise.vars import PromiseVar

# Used to replace the cookie options without replacing the value.
_NotSet = object()

accepts_final_none = is_optional(get_type_hints(StateUpdate).get("final"))


class HTTPCookie(str):
    """Represents a state Var that is stored as a secure cookie in the browser."""

    _sync_tasks: ClassVar[set[asyncio.Task]] = set()
    _has_registered_handlers: ClassVar[bool] = False

    name: str | None
    path: str
    max_age: int | None
    domain: str | None
    secure: bool
    same_site: str
    httponly: bool
    partitioned: bool
    context: dict
    _sync_on_set: bool

    def __new__(
        cls,
        object: Any = "",
        encoding: str | None = None,
        errors: str | None = None,
        /,
        name: str | None = None,
        path: str = "/",
        max_age: int | None = None,
        domain: str | None = None,
        secure: bool = True,
        same_site: str = "strict",
        partitioned: bool = False,
        _sync_on_set: bool = True,
    ):
        """Create a client-side HTTP-only Cookie (str).

        IMPORTANT: calling `.reset()` on a state does NOT clear cookies on the client.
        You must use `del state.cookie_var` to delete the cookie on the client.

        Args:
            object: The initial object.
            encoding: The encoding to use.
            errors: The error handling scheme to use.
            name: The name of the cookie on the client side.
            path: Cookie path. Use / as the path if the cookie should be accessible on all pages.
            max_age: Relative max age of the cookie in seconds from when the client receives it.
            domain: Domain for the cookie (sub.domain.com or .allsubdomains.com).
            secure: Is the cookie only accessible through HTTPS?
            same_site: Whether the cookie is sent with third party requests.
                One of (true|false|none|lax|strict)
            partitioned: Whether the cookie is partitioned (python 3.14+ only).
            _sync_on_set: Whether to sync the cookie to the client when updated.

        Returns:
            The client-side Cookie object.

        Note: expires (absolute Date) is not supported at this time.
        """
        if encoding or errors:
            inst = super().__new__(cls, object, encoding or "utf-8", errors or "strict")
        else:
            inst = super().__new__(cls, object)
        inst.name = name
        inst.path = path
        inst.max_age = max_age
        inst.domain = domain
        inst.secure = secure
        inst.same_site = same_site
        inst.httponly = True
        inst.partitioned = partitioned
        inst.context = {}
        inst._sync_on_set = _sync_on_set
        return inst

    def _replace(self, object: Any = _NotSet, /, **kwargs: Any) -> "HTTPCookie":
        """Create a new HTTPCookie with updated value and/or fields.

        Args:
            object: The new cookie value.
            **kwargs: The fields to update.

        Returns:
            A new HTTPCookie with the updated fields.
        """
        params = {
            "name": self.name,
            "path": self.path,
            "max_age": self.max_age,
            "domain": self.domain,
            "secure": self.secure,
            "same_site": self.same_site,
            "partitioned": self.partitioned,
            "_sync_on_set": self._sync_on_set,
        }
        params.update(kwargs)
        if object is _NotSet:
            object = str(self)
        return type(self)(object, **params)

    def __set_name__(self, owner: type, name: str):
        """Bind the cookie to the owning state."""
        if not name.startswith("_"):
            msg = f"HTTPCookie name must begin with '_', not {name}"
            raise TypeError(msg)
        self.context["owner"] = owner
        self.context["var_name"] = name

        # Patch some owner class methods to use the descriptor __get__ and __set__.
        original_get_skip_vars = owner.get_skip_vars
        original_init_var_dependency_dicts = owner._init_var_dependency_dicts

        @classmethod
        def get_skip_vars(_: type[BaseState]) -> set[str]:
            return original_get_skip_vars() | {name}

        @classmethod
        def _init_var_dependency_dicts(cls: type[BaseState]) -> None:
            """Remove HTTPCookie var from backend_vars after __init_subclass__."""
            original_init_var_dependency_dicts()
            # Ensure no HTTPCookie vars are in backend_vars.
            remove_vars = []
            for var_name, var_value in cls.backend_vars.items():
                if isinstance(var_value, HTTPCookie):
                    remove_vars.append(var_name)
            for name in remove_vars:
                # Hack so State __getattribute__ will pass control to this descriptor.
                cls.backend_vars.pop(name, None)
                # Hack so computed vars can depend on the cookie var.
                cls.vars[name] = rx.Var("")

        owner.get_skip_vars = get_skip_vars
        owner._init_var_dependency_dicts = _init_var_dependency_dicts

    @property
    def state(self) -> type[BaseState]:
        """Get the state that owns this cookie.

        Returns:
            The owning state.
        """
        if (owner := self.context.get("owner")) is None:
            raise RuntimeError("HTTPCookie not bound to a state")
        return owner

    @property
    def var_name(self) -> str:
        """Get the variable name of this cookie in the state.

        Returns:
            The variable name.
        """
        if (var_name := self.context.get("var_name")) is None:
            raise RuntimeError("HTTPCookie not bound to a state")
        return var_name

    @property
    def attribute_name(self) -> str:
        """Get the attribute name used to store the cookie value on the state instance."""
        return f"_http_cookie_{self.var_name}"

    @property
    def dirty_attribute_name(self) -> str:
        """Get the attribute name used to store the dirty flag on the state instance."""
        return f"{self.attribute_name}_is_dirty"

    def get_cookie_name(self) -> str:
        """Get the name of the cookie in the browser.

        Returns:
            The name of the cookie.
        """
        if self.name:
            return self.name
        return f"{self.state.get_full_name()}.{self.var_name}" + FIELD_MARKER

    def get_from_router_data(self, instance: BaseState) -> "str | None":
        """Get the cookie value from the router_data cookies.

        Args:
            instance: The state instance.

        Returns:
            The cookie value if found, None otherwise.
        """
        with contextlib.suppress(Exception):
            parsed_cookies = cookie_parser(instance.router.headers.cookie)
            return parsed_cookies[self.get_cookie_name()]
        return None

    def get_is_dirty(self, instance: BaseState) -> bool:
        """Check if the cookie is dirty for the given state instance.

        Args:
            instance: The state instance.

        Returns:
            True if the cookie needs to be written to the client, False otherwise.
        """
        with contextlib.suppress(AttributeError):
            return object.__getattribute__(instance, self.dirty_attribute_name)
        return False

    def set_is_dirty(self, instance: BaseState, is_dirty: bool) -> None:
        """Set the dirty flag for the cookie on the given state instance.

        Args:
            instance: The state instance.
            is_dirty: Whether the cookie is dirty.
        """
        object.__setattr__(instance, self.dirty_attribute_name, is_dirty)
        instance._was_touched = True  # persist dirtiness to redis

    def get_defining_state(self, instance: BaseState | None) -> BaseState:
        """Get the state that defines this cookie for the given instance.

        Args:
            instance: The state instance.

        Returns:
            The instance of the state that defines this cookie.

        Raises:
            AttributeError: If the cookie is not defined on any state in the hierarchy.
        """
        original_instance_class_name = type(instance).__name__
        while instance is not None and type(instance) is not self.state:
            instance = instance.parent_state
        if instance is None or type(instance) is not self.state:
            raise AttributeError(
                f"HTTPCookie {self.state.__name__}.{self.var_name} accessed on non-owning state {original_instance_class_name}"
            )
        return instance

    @overload
    def __get__(self, instance: None, owner: type[BaseState]) -> "HTTPCookie": ...

    @overload
    def __get__(self, instance: BaseState, owner: type[BaseState]) -> "HTTPCookie": ...

    def __get__(
        self, instance: BaseState | None, owner: type[BaseState]
    ) -> "HTTPCookie":
        """Get the cookie value from the cache or from router_data cookies."""
        if instance is None:
            return self
        # Make sure we're looking at the owning state.
        instance = self.get_defining_state(instance)
        # Start with the default
        cookie_value = self
        # Lookup value cached on the instance.
        with contextlib.suppress(AttributeError):
            cookie_value = object.__getattribute__(instance, self.attribute_name)
        # If the cookie is default/not set, then try to get it from the router data.
        if (
            cookie_value is self
            and (router_data_value := self.get_from_router_data(instance)) is not None
        ):
            cookie_value = router_data_value
        # Always return an HTTPCookie instance.
        if isinstance(cookie_value, HTTPCookie):
            return cookie_value
        return self._replace(cookie_value)

    def __set__(self, instance: BaseState, value: str) -> None:
        """Descriptor setter for the cookie value (always notifies client)."""
        self.set(instance, value)

    def __delete__(self, instance: BaseState) -> None:
        """Delete the cookie from the client by setting max_age=0."""
        self.set(instance, self._replace(max_age=0))

    def set(self, instance: BaseState, value: str, from_browser: bool = False) -> None:
        """Setter for the cookie value with optional client notification.

        Args:
            instance: The state instance.
            value: The value to set.
            from_browser: True when the value is set via a pull-from-browser request.
        """
        # Make sure we're looking at the owning state.
        instance = self.get_defining_state(instance)
        # The caller is setting the default value explicitly.
        if value is self:
            if not hasattr(instance, self.attribute_name):
                # When a cookie has never been set, do nothing.
                return
            # Otherwise, we want to delete the cookie on the client (and use the server default).
            value = self._replace(max_age=0)

        object.__setattr__(instance, self.attribute_name, value)

        # Dirty state tracking: write touched values to redis regardless of source.
        instance.dirty_vars.add(self.var_name)
        instance._mark_dirty()

        # Avoid resending values that originated from the browser.
        if from_browser:
            return

        # Dirty cookie tracking: only push values explicitly set on the backend.
        self.set_is_dirty(instance, True)
        # Notify task to push the cookie to the client if enabled (requires lost+found).
        if self._sync_on_set and (
            not isinstance(value, HTTPCookie) or value._sync_on_set
        ):
            self.notify_sync(instance)

    def notify_sync(self, instance: BaseState) -> asyncio.Task:
        """Notify the client to make an HTTP request to the backend to receive the updated cookies."""
        app = get_app().app
        t = asyncio.create_task(
            app.event_namespace.emit_update(
                update=StateUpdate(
                    events=fix_events(
                        events=[self.sync()],
                        token=instance.router.session.client_token,
                        router_data=instance.router_data,
                    ),
                    final=None if accepts_final_none else True,
                ),
                token=instance.router.session.client_token,
            )
        )
        type(self)._sync_tasks.add(t)
        t.add_done_callback(type(self)._sync_tasks.discard)
        return t

    @classmethod
    def ensure_handlers_registered(cls):
        """Ensure that the cookie sync handler is registered."""
        if cls._has_registered_handlers:
            return
        app = get_app().app
        # Prepend the route to ensure it takes priority over the proxy middleware.
        app._api.routes.insert(
            0,
            Route("/_reflex/cookies/sync", sync_cookies, methods=["POST"]),
        )
        cls._has_registered_handlers = True

    @classmethod
    @lru_cache(maxsize=8)
    def _get_sync_javascript_code(
        cls, extra_headers: tuple[tuple[str, str], ...] | None = None
    ) -> PromiseVar:
        """Get the JavaScript code to sync cookies on the client."""
        return fetch(
            get_backend_url("/_reflex/cookies/sync"),
            {
                "credentials": "include",
                "method": "POST",
                "headers": extra_headers or {},
            },
        )

    @classmethod
    def sync(
        cls,
        callback: IndividualEventType | list[IndividualEventType] | None = None,
        extra_headers: dict[str, str] | None = None,
    ) -> EventSpec:
        """Create an event spec to sync cookies with the client.

        Args:
            callback: An optional event callback to run after sync.
            extra_headers: Optional extra headers to include in the request.

        Returns:
            The event spec.
        """
        cls.ensure_handlers_registered()
        return rx.call_script(
            cls._get_sync_javascript_code(
                tuple(extra_headers.items())
                if extra_headers is not None
                else extra_headers
            ),
            callback=callback,
        )


def get_cookies_from_state_recursive(state: type[BaseState]) -> list[HTTPCookie]:
    """Get all HTTPCookie vars from the given state and its substates.

    Args:
        state: The state to get cookies from.

    Returns:
        A list of HTTPCookie descriptors found in the state.
    """
    cookies: list[HTTPCookie] = []
    parent_state = state.get_parent_state()
    for name, field in state.__fields__.items():
        # Only consider HTTPCookie fields not defined in parent states.
        if isinstance(field.default, HTTPCookie) and not hasattr(parent_state, name):
            cookies.append(field.default)
    for substate in state.get_substates():
        cookies.extend(get_cookies_from_state_recursive(substate))
    return cookies


async def sync_cookies(request: Request) -> Response:
    """HTTP Request handler to get/set cookies on the client.

    The client sends its known cookies in the request headers, and
    the server will send all modified cookies to the frontend to be set in
    the browser.

    This sync generally occurs on-demand after the backend updated cookies in
    the state.

    Args:
        request: The incoming HTTP request.

    Returns:
        An HTTP response indicating success or failure.
    """
    client_token = request.headers.get("X-Reflex-Client-Token")
    if not client_token:
        return Response("No client token in request", status_code=400)

    response = Response(status_code=200)

    app = get_app().app
    state_cls = app.state_manager.state

    async with app.modify_state(
        _substate_key(client_token, state_cls), background=True
    ) as state:
        for record in get_cookies_from_state_recursive(state):
            cookie_name = record.get_cookie_name()
            cookie_state = await state.get_state(record.state)
            if not record.get_is_dirty(cookie_state):
                # The backend has NOT modified this cookie, so set the backend value to
                # whatever the browser sent us.
                if (cookie_value := request.cookies.get(cookie_name)) is None:
                    # Browser did not send the cookie, reset it to default value.
                    cookie_value = record
                if cookie_value != record.__get__(cookie_state, owner=record.state):
                    # Set cookie value on state if different.
                    record.set(cookie_state, cookie_value, from_browser=True)
                continue
            # The backend HAS modified this cookie, so send the updated value to the browser.
            cookie_value = getattr(cookie_state, record.attribute_name)
            cookie_options = (
                cookie_value if isinstance(cookie_value, HTTPCookie) else record
            )
            response.set_cookie(
                key=record.get_cookie_name(),
                value=str(cookie_value),
                path=cookie_options.path,
                max_age=cookie_options.max_age,
                domain=cookie_options.domain,
                secure=cookie_options.secure,
                httponly=cookie_options.httponly,
                samesite=cookie_options.same_site,  # pyright: ignore[reportArgumentType]
                partitioned=cookie_options.partitioned,
            )
            # Mark the cookie as clean.
            record.set_is_dirty(cookie_state, False)
    return response



"""Drag and Drop Foreach Demo."""

import reflex as rx

import reflex_enterprise as rxe

from .common import demo


class DndForeachState(rx.State):
    """The app state."""

    drop_points: list[int] = [0, 1, 2, 3]

    card_pos: int = 0


@rx.memo
def card_foreach():
    return rxe.dnd.draggable(
        rx.card(
            rx.text("Draggable Thingy"),
            width="199px",
            height="199px",
        ),
        type="ForeachDraggable",
    )


@rx.memo
def target_foreach(pos: int = 0):
    params = rxe.dnd.DropTarget.collected_params
    return rxe.dnd.drop_target(
        rx.cond(DndForeachState.card_pos == pos, card_foreach()),
        width="200px",
        height="200px",
        border="1px solid red",
        on_drop=[
            rx.toast(f"Dropped in position {pos}"),
            DndForeachState.setvar("card_pos", pos),
        ],
        accept=["ForeachDraggable"],
        background_color=rx.cond(params.is_over, "green", "blue"),
    )


@demo(
    "/foreach",
    "Drag and Drop Foreach Demo",
    "Drag and Drop when using Foreach",
)
def foreach_page() -> rx.Component:
    return rx.container(
        rx.heading("Drag and Drop w/ Foreach"),
        rx.grid(
            rx.foreach(
                DndForeachState.drop_points,
                lambda pos: target_foreach(pos=pos),
            ),
            columns="4",
        ),
    )



import logging
from typing import ClassVar

import aiohttp
import reflex as rx

import reflex_enterprise as rxe
from reflex_enterprise.auth.cookie import HTTPCookie
from reflex_enterprise.auth.oidc.state import OIDCAuthState
from reflex_enterprise.auth.oidc.types import AsyncHTTPClientProtocol
from reflex_enterprise.utils import chain_event_out_of_band

logging.basicConfig(
    level=logging.INFO, format="%(levelname)-7s %(name)-10s: %(message)s"
)
logging.getLogger("httpx").setLevel(logging.DEBUG)
logging.getLogger("aiohttp").setLevel(logging.DEBUG)

_CACHED_HTTP_CLIENT: AsyncHTTPClientProtocol | None = None


class LogAtMixin(rx.State, mixin=True):
    # Uncomment to test with aiohttp instead of httpx
    @classmethod
    def _http_client(cls) -> AsyncHTTPClientProtocol:
        """Get the HTTP client instance for OIDC operations."""
        global _CACHED_HTTP_CLIENT
        if _CACHED_HTTP_CLIENT is None:
            _CACHED_HTTP_CLIENT = aiohttp.ClientSession()
        return _CACHED_HTTP_CLIENT

    @rx.event
    async def log_at(self):
        """Log the current authentication state."""
        access_token = await self._access_token
        self._logger.info(
            f"Userinfo: {await self.userinfo}, ID Token: {self._id_token}, Access Token: {access_token}"
        )

    @rx.var
    def last_access_token_hash(self) -> str | None:
        """A hash of the last access token for comparison to detect changes."""
        return self._last_access_token_hash


class OktaAuthState(LogAtMixin, OIDCAuthState, rx.State):
    """OIDC Auth State for Okta."""

    __provider__ = "okta"
    _logger: ClassVar[logging.Logger] = logging.getLogger(__provider__)
    _logger.setLevel(logging.DEBUG)


class DatabricksAuthState(LogAtMixin, OIDCAuthState, rx.State):
    """OIDC Auth State for Databricks."""

    __provider__ = "databricks"
    _requested_scopes: str = "all-apis offline_access openid email profile"
    _logger: ClassVar[logging.Logger] = logging.getLogger(__provider__)
    _logger.setLevel(logging.DEBUG)

    async def _on_access_token_change(self, new_access_token, refresh=False):
        self._logger.info(
            self._format_log_message(f"Access token change callback hit {refresh=}")
        )
        if refresh:
            await chain_event_out_of_band(self, rx.toast("Access token refreshed"))


class FooState(rx.State):
    @rx.event
    def do_nothing(self):
        pass


def user_info_card(auth_cls: type[OIDCAuthState]) -> rx.Component:
    return rx.card(
        rx.cond(
            auth_cls.userinfo.is_not_none(),
            rx.vstack(
                rx.heading(f"{auth_cls.__provider__.title()} User Info", size="4"),
                rx.foreach(
                    auth_cls.userinfo,
                    lambda kv: rx.text(f"{kv[0]}: {kv[1]} "),
                ),
                rx.vstack(
                    rx.badge(
                        rx.moment(auth_cls.userinfo.to(dict)["iat"], unix=True),
                        color_scheme="green",
                    ),
                    rx.badge(
                        rx.moment(auth_cls.userinfo.to(dict)["exp"], unix=True),
                        color_scheme="red",
                    ),
                    rx.badge(auth_cls.last_access_token_hash, color_scheme="blue"),
                    rx.badge(auth_cls.latest_access_token_hash_ls, color_scheme="blue"),
                )
                if auth_cls is DatabricksAuthState
                else rx.fragment(),
                rx.button(
                    "Log AT",
                    on_click=auth_cls.log_at,
                ),
                rx.button("Logout", on_click=auth_cls.redirect_to_logout),
            ),
            auth_cls.get_login_button(),
        ),
    )


def index() -> rx.Component:
    return rx.container(
        rx.color_mode.button(position="top-right"),
        rx.vstack(
            rx.heading("OIDC Demo", size="9"),
            rx.hstack(
                user_info_card(OktaAuthState),
                user_info_card(DatabricksAuthState),
                spacing="2",
            ),
            rx.button(
                "Do Nothing",
                on_click=FooState.do_nothing,
            ),
            rx.button(
                "Cookie Sync",
                on_click=HTTPCookie.sync(),
            ),
        ),
    )


def iframe() -> rx.Component:
    return rx.container(
        rx.color_mode.button(position="top-right"),
        rx.vstack(
            rx.heading("Iframed Auth"),
            rx.el.iframe(
                src="/",
                width="100%",
                height="80vh",
                border=f"1px solid {rx.color('accent', 12)}",
            ),
        ),
    )


app = rxe.App()
app.add_page(index)
app.add_page(iframe, route="/iframe")

OktaAuthState.register_auth_endpoints()
DatabricksAuthState.register_auth_endpoints()



"""Stub file for reflex_enterprise/components/mantine/base.py"""

# ------------------- DO NOT EDIT ----------------------
# This file was generated by `reflex/utils/pyi_generator.py`!
# ------------------------------------------------------
from typing import Any, Literal, Mapping, Optional, Sequence

from reflex.assets import asset
from reflex.components.core.breakpoints import Breakpoints
from reflex.event import EventType, PointerEventInfo
from reflex.vars.base import Var

from reflex_enterprise.components.component import Component, ComponentEnterprise

PACKAGE_NAME = "@mantine/core"
PACKAGE_VERSION = "8.3.9"
MantineSize = Literal["xs", "sm", "md", "lg", "xl"]
provider_path = asset(path="mantine_provider.js", shared=True)
public_provider_path = "$/public/" + provider_path

class MemoizedMantineProvider(Component):
    @classmethod
    def create(
        cls,
        *children,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        **props,
    ) -> "MemoizedMantineProvider":
        """Create the component.

        Args:
            *children: The children of the component.
            style: The style of the component.
            key: A unique key for the component.
            id: The id for the component.
            ref: The Var to pass as the ref to the component.
            class_name: The class name for the component.
            custom_attrs: custom attribute
            **props: The props of the component.

        Returns:
            The component.
        """
        ...

class MantineCoreBase(ComponentEnterprise):
    def add_imports(self): ...
    @classmethod
    def create(
        cls,
        *children,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        **props,
    ) -> "MantineCoreBase":
        """Create the Reflex Enterprise component."""
        ...

class MantineLeftSection(ComponentEnterprise):
    @classmethod
    def create(
        cls,
        *children,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        **props,
    ) -> "MantineLeftSection":
        """Create the Reflex Enterprise component."""
        ...

class MantineRightSection(ComponentEnterprise):
    @classmethod
    def create(
        cls,
        *children,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        **props,
    ) -> "MantineRightSection":
        """Create the Reflex Enterprise component."""
        ...

class BaseMantineInput(MantineCoreBase, MantineLeftSection, MantineRightSection):
    @classmethod
    def create(
        cls,
        *children,
        clearable: Var[bool] | bool | None = None,
        placeholder: Var[str] | str | None = None,
        multiline: Var[bool] | bool | None = None,
        read_only: Var[bool] | bool | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        left_section: Component | Var[Component | str] | str | None = None,
        left_section_props: Var[dict] | dict | None = None,
        left_section_width: Var[float | str] | float | str | None = None,
        left_section_pointer_events: Var[str] | str | None = None,
        right_section: Component | Var[Component | str] | str | None = None,
        right_section_props: Var[dict] | dict | None = None,
        right_section_width: Var[float | str] | float | str | None = None,
        right_section_pointer_events: Var[str] | str | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        **props,
    ) -> "BaseMantineInput":
        """Create the Reflex Enterprise component."""
        ...

class MantineDescriptionProps(MantineCoreBase):
    @classmethod
    def create(
        cls,
        *children,
        description: Component | Var[Component | str] | str | None = None,
        description_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        **props,
    ) -> "MantineDescriptionProps":
        """Create the Reflex Enterprise component."""
        ...

class MantineErrorProps(MantineCoreBase):
    @classmethod
    def create(
        cls,
        *children,
        error: Component | Var[Component | bool | str] | bool | str | None = None,
        error_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        **props,
    ) -> "MantineErrorProps":
        """Create the Reflex Enterprise component."""
        ...

class MantineLabelProps(MantineCoreBase):
    @classmethod
    def create(
        cls,
        *children,
        label: Component | Var[Component | str] | str | None = None,
        label_props: Var[dict] | dict | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        **props,
    ) -> "MantineLabelProps":
        """Create the Reflex Enterprise component."""
        ...



"""Aspect Ratio demo page."""

import reflex as rx

import reflex_enterprise as rxe

from .common import demo


@demo(
    route="/aspect-ratio",
    title="Aspect Ratio",
    description="An aspect ratio is used to maintain the aspect ratio of a component.",
)
def aspect_ratio_page():
    """Aspect ratio demo page."""
    return rx.hstack(
        rxe.aspect_ratio(
            rx.image(
                src="https://reflex.dev/logo.jpg",
            ),
            ratio=1 / 1,
        ),
        align="center",
        spacing="4",
    )



"""Stub file for reflex_enterprise/components/ag_grid/handlers.py"""

# ------------------- DO NOT EDIT ----------------------
# This file was generated by `reflex/utils/pyi_generator.py`!
# ------------------------------------------------------
from types import SimpleNamespace
from typing import Any, Type, TypeVar

import reflex as rx
from sqlalchemy.orm.attributes import InstrumentedAttribute
from sqlalchemy.sql.roles import WhereHavingRole
from sqlmodel import and_, or_
from sqlmodel.sql.expression import SelectOfScalar

M = TypeVar("M", bound=rx.Model)

def handle_text_filter(value: str, filter_def: dict[str, str]) -> bool: ...
def handle_number_filter(value: int, filter_def: dict) -> bool: ...
def handle_filter_def(value: Any, filter_def: dict) -> bool: ...
def handle_filter_model(row: list, filter_model: dict) -> bool: ...

_sql_operations = {"and": and_, "or": or_}

def where_text_filter(
    value: InstrumentedAttribute, filter_def: dict[str, str]
) -> WhereHavingRole: ...
def where_number_filter(
    value: InstrumentedAttribute, filter_def: dict[str, str | int | float]
) -> WhereHavingRole: ...
def where_filter_def(
    value: InstrumentedAttribute, filter_def: dict[str, Any]
) -> WhereHavingRole | None: ...
def where_filter_outer_def(
    model: Type[M], filter_def: dict[str, Any]
) -> WhereHavingRole | None: ...
def apply_filter_model(
    model: Type[M], filter_model: dict[str, dict[str, Any]]
) -> SelectOfScalar[M]: ...
def apply_sort_model(
    model: Type[M], query: SelectOfScalar[M], sort_model: list[dict[str, str]]
) -> SelectOfScalar[M]: ...

class HandlerNamespace(SimpleNamespace):
    text_filter = handle_text_filter



"""Stub file for reflex_enterprise/components/mantine/number_formatter.py"""

# ------------------- DO NOT EDIT ----------------------
# This file was generated by `reflex/utils/pyi_generator.py`!
# ------------------------------------------------------
from typing import Any, Literal, Mapping, Optional, Sequence

from reflex.components.core.breakpoints import Breakpoints
from reflex.event import EventType, PointerEventInfo
from reflex.vars.base import Var

from reflex_enterprise.components.mantine.base import MantineCoreBase

class NumberFormatter(MantineCoreBase):
    @classmethod
    def create(
        cls,
        *children,
        allow_negative: Var[bool] | bool | None = None,
        decimal_scale: Var[int] | int | None = None,
        decimal_separator: Var[str] | str | None = None,
        fixed_decimal_scale: Var[bool] | bool | None = None,
        prefix: Var[str] | str | None = None,
        suffix: Var[str] | str | None = None,
        thousand_separator: Var[bool | str] | bool | str | None = None,
        thousands_group_style: Literal["lakh", "none", "thousand", "wan"]
        | Var[Literal["lakh", "none", "thousand", "wan"]]
        | None = None,
        value: Var[float | int | str] | float | int | str | None = None,
        style: Sequence[Mapping[str, Any]]
        | Mapping[str, Any]
        | Var[Mapping[str, Any]]
        | Breakpoints
        | None = None,
        key: Any | None = None,
        id: Any | None = None,
        ref: Var | None = None,
        class_name: Any | None = None,
        custom_attrs: dict[str, Var | Any] | None = None,
        on_blur: Optional[EventType[()]] = None,
        on_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_context_menu: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_double_click: Optional[EventType[()] | EventType[PointerEventInfo]] = None,
        on_focus: Optional[EventType[()]] = None,
        on_mount: Optional[EventType[()]] = None,
        on_mouse_down: Optional[EventType[()]] = None,
        on_mouse_enter: Optional[EventType[()]] = None,
        on_mouse_leave: Optional[EventType[()]] = None,
        on_mouse_move: Optional[EventType[()]] = None,
        on_mouse_out: Optional[EventType[()]] = None,
        on_mouse_over: Optional[EventType[()]] = None,
        on_mouse_up: Optional[EventType[()]] = None,
        on_scroll: Optional[EventType[()]] = None,
        on_scroll_end: Optional[EventType[()]] = None,
        on_unmount: Optional[EventType[()]] = None,
        **props,
    ) -> "NumberFormatter":
        """Create the Reflex Enterprise component."""
        ...

number_formatter = NumberFormatter.create



"""Enterprise app class."""

from reflex.app import App
from reflex.config import get_config
from reflex.utils import console
from reflex.utils.exec import is_prod_mode
from reflex_cli.utils.hosting import save_token_to_config

from reflex_enterprise import constants
from reflex_enterprise.config import ConfigEnterprise
from reflex_enterprise.environment import environment
from reflex_enterprise.utils import (
    check_config_option_in_tier,
    get_user_tier,
    is_deploy_context,
    is_new_session,
)


class AppEnterprise(App):
    """Enterprise app class."""

    def __post_init__(self):
        """Post-initialization."""
        super().__post_init__()
        self._check_and_setup_access_token()
        self._check_login()
        self._verify_and_setup_badge()
        self._verify_and_setup_proxy()

    def _check_and_setup_access_token(self):
        if environment.REFLEX_ACCESS_TOKEN.is_set():
            access_token = environment.REFLEX_ACCESS_TOKEN.get()
            if access_token is not None:
                save_token_to_config(access_token)

    def _check_login(self):
        """Check if the user is logged in.

        Raises:
            RuntimeError: If the user is not logged in.
        """
        current_tier = get_user_tier()
        if (
            current_tier == "anonymous"
            and not environment.REFLEX_BACKEND_ONLY.get()
            and not environment.CI.get()
        ):
            msg = (
                "`reflex-enterprise` is free to use but you must be logged in. "
                "Run `reflex login` or set the environment variable REFLEX_ACCESS_TOKEN with your token."
            )
            console.error(msg)
            exit()

    def _verify_and_setup_badge(self):
        config = get_config()
        deploy = is_deploy_context()

        check_config_option_in_tier(
            option_name="show_built_with_reflex",
            allowed_tiers=(
                ["pro", "team", "enterprise"] if deploy else ["team", "enterprise"]
            ),
            fallback_value=True,
            help_link=constants.SHOW_BUILT_WITH_REFLEX_INFO,
        )

        if is_prod_mode() and config.show_built_with_reflex:
            self._setup_sticky_badge()

    def _verify_and_setup_proxy(self):
        config = get_config()
        deploy = is_deploy_context()

        if (
            isinstance(config, ConfigEnterprise)
            and config.use_single_port
            and not environment.REFLEX_BACKEND_ONLY.get()
        ):
            if deploy:
                console.warn(
                    "Single port mode is not supported when deploying to Reflex Cloud. Ignoring the setting."
                )
                return
            if is_new_session():
                console.info("Single port proxy mode enabled")
            # Enable proxying to frontend server.
            from .proxy import proxy_middleware

            self.register_lifespan_task(proxy_middleware)


App = AppEnterprise



"""Stub file for reflex_enterprise/components/ag_grid/resource.py"""

# ------------------- DO NOT EDIT ----------------------
# This file was generated by `reflex/utils/pyi_generator.py`!
# ------------------------------------------------------
from types import SimpleNamespace
from typing import Any

import reflex as rx
from reflex.components.props import PropsBase
from reflex.vars import LiteralStringVar
from reflex.vars.base import Var
from reflex.vars.function import ArgsFunctionOperation

from reflex_enterprise.utils import arrow_func

def value_func_factory(
    return_expr: str | Var[str], known_components: list[str] | None = None
) -> ArgsFunctionOperation | LiteralStringVar: ...

class AGFilters(SimpleNamespace):
    text = "agTextColumnFilter"
    number = "agNumberColumnFilter"
    date = "agDateColumnFilter"
    set = "agSetColumnFilter"
    multi = "agMultiColumnFilter"

class AGAggregations(SimpleNamespace):
    sum = "sum"
    count = "count"
    min = "min"
    max = "max"
    avg = "avg"
    first = "first"
    last = "last"

class AGEditors(SimpleNamespace):
    text = "agTextCellEditor"
    large_text = "agLargeTextCellEditor"
    select = "agSelectCellEditor"
    rich_select = "agRichSelectCellEditor"
    number = "agNumberCellEditor"
    date = "agDateCellEditor"
    date_string = "agDateStringCellEditor"
    checkbox = "agCheckboxCellEditor"

class RendererParams(rx.Base):
    value: str
    data: dict[str, Any]
    node: Any
    column: Any
    context: Any
    valueFormatted: str

class AGRenderers(SimpleNamespace):
    @arrow_func
    @staticmethod
    def link(params: RendererParams): ...
    @arrow_func
    @staticmethod
    def link_external(params: RendererParams): ...
    @arrow_func
    @staticmethod
    def image(params: RendererParams): ...
    checkbox_cell = "agCheckboxCellRenderer"
    group_cell = "agGroupCellRenderer"
    loading_cell = "agLoadingCellRenderer"
    skeleton_cell = "agSkeletonCellRenderer"
    animate_show_change_cell = "agAnimateShowChangeCellRenderer"
    animate_slide_cell = "agAnimateSlideCellRenderer"
    rich_select_cell = "agRichSelectCellRenderer"
    popup_cell = "agPopupCellRenderer"

class AGStatusPanels(SimpleNamespace):
    total: str
    filtered: str
    filtered_total: str
    selected: str
    aggregation: str

class StatusPanelDef(PropsBase):
    status_panel: str | Var[str]
    status_panel_params: dict[str, Any] | Var[dict[str, Any]] | None
    align: str | Var[str] | None
    key: str | Var[str] | None

class ToolPanelDef(PropsBase):
    id: str
    label_key: str
    label_default: str
    min_width: int | Var[int] | None
    max_width: int | Var[int] | None
    width: int | Var[int] | None

class SideBarDef(PropsBase):
    tool_panels: list[str | ToolPanelDef] | Var[list[str | ToolPanelDef]]
    default_tool_panel: str | Var[str] | None
    hidden_by_default: bool | Var[bool]
    position: str | Var[str] | None

def get_builtin_components() -> list[str]: ...
